import * as CHARACTER from "./character.mjs"
import * as WEAPON from "./weapon.mjs"
import * as ARMOR from "./armor.mjs"
import * as SPELL from "./spell.mjs"
import * as SKILL from "./skill.mjs"
import * as EQUIPMENT from "./equipment.mjs"
import * as CHARACTERISTICS from "./characteristic-tables.mjs"

export const SYSTEM_ID = "fvtt-lethal-fantasy"
export const DEV_MODE = false

export const MONEY = {
  tinbit: {
    id: "tinbit",
    abbrev: "tb",
    label: "LETHALFANTASY.Money.Tinbits",
    valuetb: 1
  },
  copper: {
    id: "copper",
    abbrev: "cp",
    label: "LETHALFANTASY.Money.Coppers",
    valuetb: 10
  },
  silver: {
    id: "silver",
    abbrev: "sp",
    label: "LETHALFANTASY.Money.Silvers",
    valuetb: 100
  },
  gold: {
    id: "gold",
    abbrev: "gp",
    label: "LETHALFANTASY.Money.Golds",
    valuetb: 1000
  },
  platinum: {
    id: "platinum",
    abbrev: "pp",
    label: "LETHALFANTASY.Money.Platinums",
    valuetb: 10000
  }
}

export const DICE_VALUES = {
  "d3": "D3",  
  "d4": "D4",
  "d6": "D6",
  "d8": "D8",
  "d10": "D10",
  "d12": "D12",
  "d20": "D20"
}

export const CHARACTERISTIC_ATTACK = [ "str", "int", "wis", "dex"]
export const CHARACTERISTIC_DEFENSE = [ "int", "wis", "dex" ]
export const CHARACTERISTIC_DAMAGE = [ "str" ]

export const DEFENSE_DICE_VALUES = {
  "d3": "D3",  
  "d4": "D4",
  "d6": "D6",
  "d8": "D8",
  "d10": "D10"
}

export const CHOICE_DICE = {
  "D4": "D4",
  "D6": "D6",
  "D8": "D8",
  "D10": "D10",
  "D12": "D12",
  "D20": "D20"
}

export const CHOICE_MODIFIERS = {
    "-9": "-9",
    "-8": "-8",
    "-7": "-7",
    "-6": "-6",
    "-5": "-5",
    "-4": "-4",
    "-3": "-3",
    "-2": "-2",
    "-1": "-1",
    "+0": "0",
    "+1": "+1",
    "+2": "+2",
    "+3": "+3",
    "+4": "+4",
    "+5": "+5",
    "+6": "+6",
    "+7": "+7",
    "+8": "+8",
    "+9": "+9",
    "+10": "+10",
    "+11": "+11",
    "+12": "+12",
    "+13": "+13",
    "+14": "+14",
    "+15": "+15",
    "+16": "+16",
    "+17": "+17",
    "+18": "+18",
    "+19": "+19",
    "+20": "+20",
    "+21": "+21",
    "+22": "+22",
    "+23": "+23",
    "+24": "+24",
    "+25": "+25"
}

export const ASCII = `
······················································································································
:                                                                                                                    :
:@@@      @@@@@@@@ @@@@@@@ @@@  @@@  @@@@@@  @@@         @@@@@@@@  @@@@@@  @@@  @@@ @@@@@@@  @@@@@@   @@@@@@ @@@ @@@ :
:@@!      @@!        @!!   @@!  @@@ @@!  @@@ @@!         @@!      @@!  @@@ @@!@!@@@   @!!   @@!  @@@ !@@     @@! !@@ :
:@!!      @!!!:!     @!!   @!@!@!@! @!@!@!@! @!!         @!!!:!   @!@!@!@! @!@@!!@!   @!!   @!@!@!@!  !@@!!   !@!@!  :
:!!:      !!:        !!:   !!:  !!! !!:  !!! !!:         !!:      !!:  !!! !!:  !!!   !!:   !!:  !!!     !:!   !!:   :
:: ::.: : : :: ::     :     :   : :  :   : : : ::.: :     :        :   : : ::    :     :     :   : : ::.: :    .:    :
:                                                                                                                    :
······················································································································
`

/**
 * Include all constant definitions within the SYSTEM global export
 * @type {Object}
 */
export const SYSTEM = {
  id: SYSTEM_ID,
  CHARACTERISTICS: CHARACTER.CHARACTERISTICS,
  CHARACTERISTICS_TABLES: CHARACTERISTICS.TABLES,
  CHARACTERISTICS_MAJOR: CHARACTERISTICS.MAJOR, 
  SAVES: CHARACTER.SAVES,
  CHALLENGES: CHARACTER.CHALLENGES,
  SKILL_CATEGORY: SKILL.CATEGORY,
  ARMOR_TYPE: ARMOR.TYPE,
  EQUIPMENT_CATEGORY: EQUIPMENT.CATEGORY,
  SPELL_RANGE: SPELL.RANGE,
  WEAPON_TYPE: WEAPON.WEAPON_TYPE,
  WEAPON_CLASS: WEAPON.WEAPON_CLASS,
  COMBAT_PROGRESSION_DICE: DICE_VALUES,
  SHIELD_DEFENSE_DICE: DEFENSE_DICE_VALUES,
  WEAPON_CATEGORIES: WEAPON.WEAPON_CATEGORIES,
  CHARACTERISTIC_ATTACK,
  CHARACTERISTIC_DEFENSE,
  CHARACTERISTIC_DAMAGE,
  MONEY,
  ASCII,
  CHOICE_MODIFIERS,
  CHOICE_DICE,
  DEV_MODE,
}
